==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/user/messages/vi/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => 'Đăng ký <strong>Tài khoản</strong>',
  '<strong>Change</strong> your password' => '<strong>Đổi</strong> mật khẩu của bạn',
  '<strong>Join</strong> the network' => '<strong>Tham gia</strong> hệ thống mạng',
  '<strong>Password</strong> changed!' => '<strong>Mật khẩu</strong> đã được thay đổi!',
  '<strong>Password</strong> recovery' => 'Khôi phục <strong>Mật khẩu</strong>',
  '<strong>Password</strong> recovery!' => 'Khôi phục <strong>Mật khẩu</strong>!',
  '<strong>Please</strong> sign in' => '<strong>Vui lòng</strong> đăng nhập',
  '<strong>Registration</strong> successful!' => '<strong>Đăng ký</strong> thành công!',
  '<strong>Sign</strong> up' => '<strong>Đăng ký</strong>',
  '<strong>Your account</strong> has been successfully created!' => '<strong>Tài khoản của bạn</strong> đã được tạo thành công!',
  'Account' => 'Tài khoản',
  'After activating your account by the administrator, you will receive a notification by email.' => 'Sau khi kích hoạt tài khoản bởi quản trị hệ thống, bạn sẽ nhận được thông báo qua email.',
  'Back' => 'Trở lại',
  'Change password' => 'Đổi mật khẩu',
  'Create Account' => 'Tạo tài khoản',
  'Create account' => 'Tạo tài khoản',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'Chưa có tài khoản? Tham gia hệ thống mạng bằng cách nhập email của bạn.',
  'Enter security code above' => 'Nhập vào mã bảo mật ở trên',
  'Forgot your password?' => 'Quên mật khẩu?',
  'Go to login page' => 'Truy cập trang đăng nhập',
  'Group' => '',
  'Hello {displayName}' => 'Xin chào {displayName}',
  'Hello {displayName},' => 'Xin chào {displayName},',
  'If you don\'t use this link within 24 hours, it will expire.' => 'Liêt kết sẽ hết hạn trong vòng 24 giờ.',
  'If you\'re already a member, please login with your username/email and password.' => 'Nếu bạn đã là thành viên, vui lòng đăng nhập bằng tên truy cập (hoặc email) và mật khẩu.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Nhập email của bạn. Chúng tôi sẽ gửi bạn hướng dẫn khôi phục',
  'Login' => 'Đăng nhập',
  'New user needs approval' => 'Người dùng mới cần được xét duyệt',
  'Password recovery' => 'Khôi phục mật khẩu',
  'Password reset' => 'Đặt lại mật khẩu',
  'Please check your email and follow the instructions!' => 'Vui lòng kiểm tra email và làm theo hướng dẫn trong mail!',
  'Please click on the link below to view request:' => 'Vui lòng click link dưới đây để xem yêu cầu',
  'Please enter the letters from the image.' => '',
  'Please login with your username/email and password.' => 'Vui lòng đăng nhập bằng tên truy cập (hoặc email) và mật khẩu.',
  'Please use the following link within the next day to reset your password.' => 'Vui lòng sử dụng link sau chậm nhất trong ngày làm việc tiếp theo để thiết lập lại mật khẩu.',
  'Register' => 'Đăng ký',
  'Registration successful' => 'Đăng ký thành công',
  'Remember me' => 'Ghi nhớ tôi trên trình duyệt này',
  'Reset Password' => 'Đặt lại mật khẩu',
  'Reset password' => 'Đặt lại mật khẩu',
  'Sign in' => 'Đăng nhập',
  'To log in with your new account, click the button below.' => 'Để đăng nhập bằng tài khoản mới, click nút dưới đây.',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'Chúng tôi vừa gửi bạn email có chứa liên kết để thiết lập lại mật khẩu.',
  'Your email' => 'địa chỉ email của bạn',
  'Your password' => 'Mật khẩu của bạn',
  'Your password has been successfully changed!' => 'Mật khẩu của bạn đã được đổi thành công!',
  'Your password is incorrect!' => 'Sai mật khẩu!',
  'a new user {displayName} needs approval.' => 'Một người dùng mới {displayName} cần xét duyệt.',
  'back to home' => 'trở lại trang chủ',
  'email' => 'email',
  'password' => 'mật khẩu',
  'username or email' => 'tên truy cập hoặc email',
);

==> humhub-1.6.4.tar.gz: humhub-1.6.4/protected/humhub/modules/user/messages/vi/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => 'Đăng ký <strong>Tài khoản</strong>',
  '<strong>Change</strong> your password' => '<strong>Đổi</strong> mật khẩu của bạn',
  '<strong>Join</strong> the network' => '<strong>Tham gia</strong> hệ thống mạng',
  '<strong>Password</strong> changed!' => '<strong>Mật khẩu</strong> đã được thay đổi!',
  '<strong>Password</strong> recovery' => 'Khôi phục <strong>Mật khẩu</strong>',
  '<strong>Password</strong> recovery!' => 'Khôi phục <strong>Mật khẩu</strong>!',
  '<strong>Please</strong> sign in' => '<strong>Vui lòng</strong> đăng nhập',
  '<strong>Registration</strong> successful!' => '<strong>Đăng ký</strong> thành công!',
  '<strong>Sign</strong> up' => '<strong>Đăng ký</strong>',
  '<strong>Your account</strong> has been successfully created!' => '<strong>Tài khoản của bạn</strong> đã được tạo thành công!',
  'Account' => 'Tài khoản',
  'After activating your account by the administrator, you will receive a notification by email.' => 'Sau khi kích hoạt tài khoản bởi quản trị hệ thống, bạn sẽ nhận được thông báo qua email.',
  'Back' => 'Trở lại',
  'Change password' => 'Đổi mật khẩu',
  'Create Account' => 'Tạo tài khoản',
  'Create account' => 'Tạo tài khoản',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'Chưa có tài khoản? Tham gia hệ thống mạng bằng cách nhập email của bạn.',
  'Enter security code above' => 'Nhập vào mã bảo mật ở trên',
  'Forgot your password?' => 'Quên mật khẩu?',
  'Go to login page' => 'Truy cập trang đăng nhập',
  'Group' => 'Nhóm',
  'Hello {displayName}' => 'Xin chào {displayName}',
  'Hello {displayName},' => 'Xin chào {displayName},',
  'If you don\'t use this link within 24 hours, it will expire.' => 'Liêt kết sẽ hết hạn trong vòng 24 giờ.',
  'If you\'re already a member, please login with your username/email and password.' => 'Nếu bạn đã là thành viên, vui lòng đăng nhập bằng tên truy cập (hoặc email) và mật khẩu.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Nhập email của bạn. Chúng tôi sẽ gửi bạn hướng dẫn khôi phục',
  'Login' => 'Đăng nhập',
  'New user needs approval' => 'Người dùng mới cần được xét duyệt',
  'Password recovery' => 'Khôi phục mật khẩu',
  'Password reset' => 'Đặt lại mật khẩu',
  'Please check your email and follow the instructions!' => 'Vui lòng kiểm tra email và làm theo hướng dẫn trong mail!',
  'Please click on the link below to view request:' => 'Vui lòng click link dưới đây để xem yêu cầu',
  'Please enter the letters from the image.' => 'Vui lòng điền các ký tự từ hình ảnh.',
  'Please login with your username/email and password.' => 'Vui lòng đăng nhập bằng tên truy cập (hoặc email) và mật khẩu.',
  'Please use the following link within the next day to reset your password.' => 'Vui lòng sử dụng link sau chậm nhất trong ngày làm việc tiếp theo để thiết lập lại mật khẩu.',
  'Register' => 'Đăng ký',
  'Registration successful' => 'Đăng ký thành công',
  'Remember me' => 'Ghi nhớ tôi trên trình duyệt này',
  'Reset Password' => 'Đặt lại mật khẩu',
  'Reset password' => 'Đặt lại mật khẩu',
  'Sign in' => 'Đăng nhập',
  'To log in with your new account, click the button below.' => 'Để đăng nhập bằng tài khoản mới, click nút dưới đây.',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'Chúng tôi vừa gửi bạn email có chứa liên kết để thiết lập lại mật khẩu.',
  'Your email' => 'địa chỉ email của bạn',
  'Your password' => 'Mật khẩu của bạn',
  'Your password has been successfully changed!' => 'Mật khẩu của bạn đã được đổi thành công!',
  'Your password is incorrect!' => 'Sai mật khẩu!',
  'a new user {displayName} needs approval.' => 'Một người dùng mới {displayName} cần xét duyệt.',
  'back to home' => 'trở lại trang chủ',
  'email' => 'email',
  'password' => 'mật khẩu',
  'username or email' => 'tên truy cập hoặc email',
);
